pub struct BandRssiAdjustment {
pub band: WlanBand,
pub rssi_adjustment: i8,
}Expand description
An adjustment to be made to the observed RSSI values for BSSs in the specified band.
Fields
band: WlanBandrssi_adjustment: i8Trait Implementations
Sourceimpl Clone for BandRssiAdjustment
impl Clone for BandRssiAdjustment
Sourcefn clone(&self) -> BandRssiAdjustment
fn clone(&self) -> BandRssiAdjustment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BandRssiAdjustment
impl Debug for BandRssiAdjustment
Sourceimpl<D: ResourceDialect> Decode<BandRssiAdjustment, D> for BandRssiAdjustment
impl<D: ResourceDialect> Decode<BandRssiAdjustment, D> for BandRssiAdjustment
Sourceimpl<D: ResourceDialect> Encode<BandRssiAdjustment, D> for &BandRssiAdjustment
impl<D: ResourceDialect> Encode<BandRssiAdjustment, D> for &BandRssiAdjustment
Sourceimpl<D: ResourceDialect, T0: Encode<WlanBand, D>, T1: Encode<i8, D>> Encode<BandRssiAdjustment, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<WlanBand, D>, T1: Encode<i8, D>> Encode<BandRssiAdjustment, D> for (T0, T1)
Sourceimpl Hash for BandRssiAdjustment
impl Hash for BandRssiAdjustment
Sourceimpl Ord for BandRssiAdjustment
impl Ord for BandRssiAdjustment
Sourcefn cmp(&self, other: &BandRssiAdjustment) -> Ordering
fn cmp(&self, other: &BandRssiAdjustment) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BandRssiAdjustment
impl PartialEq for BandRssiAdjustment
Sourceimpl PartialOrd for BandRssiAdjustment
impl PartialOrd for BandRssiAdjustment
Sourceimpl TypeMarker for BandRssiAdjustment
impl TypeMarker for BandRssiAdjustment
Sourcetype Owned = BandRssiAdjustment
type Owned = BandRssiAdjustment
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BandRssiAdjustment
impl ValueTypeMarker for BandRssiAdjustment
Sourcetype Borrowed<'a> = &'a BandRssiAdjustment
type Borrowed<'a> = &'a BandRssiAdjustment
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for BandRssiAdjustment
impl Eq for BandRssiAdjustment
impl Persistable for BandRssiAdjustment
impl StructuralPartialEq for BandRssiAdjustment