pub struct ScheduledScanMatchSet {
pub ssid: Option<Vec<u8>>,
pub bssid: Option<[u8; 6]>,
pub min_rssi_threshold: Option<i8>,
pub relative_rssi_threshold: Option<i8>,
pub band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>,
/* private fields */
}Expand description
A nested set of attributes to match during scheduled scans. A BSS must meet ALL of the present criteria in the match set to be considered a match.
Since not all hardware supports matching all types of attributes, there is no guarantee that the reported BSSs are fully compliant with the match sets. A driver may return EINVAL if it cannot support a match set, or may ignore the match criteria.
Fields
ssid: Option<Vec<u8>>Optional.
bssid: Option<[u8; 6]>Optional.
min_rssi_threshold: Option<i8>Optional. Minimum RSSI threshold to be applied to all BSSs.
relative_rssi_threshold: Option<i8>Optional. RSSI value delta, relative to the current connected BSS’s RSSI to satisfy the match set. May be negative (i.e. -5 dB would require an observed BSS’s RSSI to be no less than the current RSSI - 5 dB). If not currently connected, this field is ignored.
band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>Optional. RSSI band adjustments to make to observed RSSI values before comparing to the minimum and relative RSSI thresholds.