pub struct ScheduledScanRequest {
pub scan_plans: Option<Vec<ScheduledScanPlan>>,
pub ssids: Option<Vec<Vec<u8>>>,
pub frequencies: Option<Vec<u32>>,
pub min_rssi_threshold: Option<i8>,
pub relative_rssi_threshold: Option<i8>,
pub band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>,
pub match_sets: Option<Vec<ScheduledScanMatchSet>>,
/* private fields */
}Expand description
Request for scheduled scanning.
Fields
scan_plans: Option<Vec<ScheduledScanPlan>>Required: one or more scan plans, to be run consecutively. In some firmware implementations, the last scan plan may run indefinitely, regardless of the iterations field value.
ssids: Option<Vec<Vec<u8>>>Optional. Zero or more SSIDs to scan for.
If present, SSIDs should be included in probe requests. If an empty string is present, a broadcast SSID should be sent in probe requests. If the vector is empty or not present, only passive scanning should be performed.
frequencies: Option<Vec<u32>>Optional. Zero or more channel frequencies that should be scanned. If empty or not present, all channels for the regulatory domain will be scanned.
min_rssi_threshold: Option<i8>Optional. Minimum RSSI threshold to be applied to all BSSs.
relative_rssi_threshold: Option<i8>Optional. RSSI value delta, relative to the current connected BSS’s RSSI to satisfy the match set. May be negative (i.e. -5 dB would require an observed BSS’s RSSI to be no less than the current RSSI - 5 dB). If not currently connected, this field is ignored.
band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>Optional. RSSI band adjustments to make to observed RSSI values before comparing to the minimum and relative RSSI thresholds.
match_sets: Option<Vec<ScheduledScanMatchSet>>Zero or more sets of match criteria.
If present, only BSSs that pass through the top-level RSSI threshold filters AND match any of the match sets will be reported.